@@ -4,13 +4,12 @@
 # See the NOTICE for more information.
 
 
-version_info = (0, 1, 0)
+version_info = (0, 2, 0)
 __version__ = ".".join(map(str, version_info))
 
 
 try:
-    from webmachine.api import wm
-    from webmachine.sites import Site, site
+    from webmachine.api import WM, wm
     from webmachine.resource import Resource
 except ImportError:
     import traceback
@@ -23,7 +22,6 @@ def autodiscover():
     may want.
     """
 
-    import copy
     from django.conf import settings
     from django.utils.importlib import import_module
     from django.utils.module_loading import module_has_submodule
@@ -32,9 +30,7 @@ def autodiscover():
         mod = import_module(app)
         # Attempt to import the app's resource module.
         try:
-            before_import_registry = copy.copy(site._registry)
             import_module('%s.resources' % app)
         except:
-            site._registry = before_import_registry
             if module_has_submodule(mod, 'resources'):
                 raise 
