@@ -9,7 +9,7 @@ import uuid
 from django.contrib.auth.models import User
 from django.db import models
 
-from webmachine.const import SECRET_SIZE
+from webmachine.util.const import SECRET_SIZE
 
 class KeyManager(models.Manager):
 
